@@ -1,9 +1,10 @@
 /*
- * Copyright 1999-2002,2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -35,7 +36,7 @@ import org.w3c.dom.Element;
  * 
  * @xerces.internal
  *
- * @version $Id: DOMImplementationImpl.java,v 1.33 2004/10/05 17:12:49 mrglavas Exp $
+ * @version $Id: DOMImplementationImpl.java 516291 2007-03-09 04:26:22Z mrglavas $
  * @since  PR-DOM-Level-1-19980818.
  */
 public class DOMImplementationImpl extends CoreDOMImplementationImpl
@@ -129,18 +130,16 @@ public class DOMImplementationImpl extends CoreDOMImplementationImpl
                                              DocumentType doctype)
                                              throws DOMException
     {
-        if(namespaceURI == null && qualifiedName == null && doctype == null){
-        //if namespaceURI, qualifiedName and doctype are null, returned document is empty with
-        //no document element
-            return new DocumentImpl();
-        }
-    	else if (doctype != null && doctype.getOwnerDocument() != null) {
+        if (doctype != null && doctype.getOwnerDocument() != null) {
             String msg = DOMMessageFormatter.formatMessage(DOMMessageFormatter.DOM_DOMAIN, "WRONG_DOCUMENT_ERR", null);
             throw new DOMException(DOMException.WRONG_DOCUMENT_ERR, msg);
         }
         DocumentImpl doc = new DocumentImpl(doctype);
-        Element e = doc.createElementNS( namespaceURI, qualifiedName);
-        doc.appendChild(e);
+        // If namespaceURI and qualifiedName are null return a Document with no document element.
+        if (qualifiedName != null || namespaceURI != null) {
+            Element e = doc.createElementNS(namespaceURI, qualifiedName);
+            doc.appendChild(e);
+        }
         return doc;
     }
 
